; Gabriel benchmarks
(define boyer-iters 1)
(define browse-iters 1)
(define cpstak-iters 1)
(define ctak-iters 1)
(define dderiv-iters 1)
(define deriv-iters 1)
(define destruc-iters 1)
(define diviter-iters 1)
(define divrec-iters 1)
(define puzzle-iters 1)
(define tak-iters 1)
(define takl-iters 1)
(define trav1-iters 1)
(define trav2-iters 1)
(define triangl-iters 1)

; Kernighan and Van Wyk benchmarks
(define ack-iters 1)
(define array1-iters 1)
(define cat-iters 1)
(define string-iters 1)
(define sum1-iters 1)
(define sumloop-iters 1)
(define tail-iters 1)
(define wc-iters 1)

; C benchmarks
(define fft-iters 1)
(define fib-iters 1)
(define fibfp-iters 1)
(define mbrot-iters 1)
(define nucleic-iters 1)
(define pnpoly-iters 1)
(define sum-iters 1)
(define sumfp-iters 1)
(define tfib-iters 1)

; Other benchmarks
(define conform-iters 1)
(define dynamic-iters 1)
(define earley-iters 1)
(define fibc-iters 1)
(define fftrad4-iters 1)
(define graphs-iters 1)
(define lattice-iters 1)
(define matrix-iters 1)
(define maze-iters 1)
(define mazefun-iters 1)
(define nqueens-iters 1)
(define paraffins-iters 1)
(define peval-iters 1)
(define pi-iters 1)
(define primes-iters 1)
(define ray-iters 1)
(define scheme-iters 1)
(define simplex-iters 1)
(define slatex-iters 1)
(define perm9-iters 1)
(define nboyer-iters 1)
(define sboyer-iters 1)
(define gcbench-iters 1)
(define compiler-iters 1)
(define chud100K-iters 1)
(define chud1K-iters 1)
(define pi10K-iters 1)
